Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
aiopromql/__init__.py | 3 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | 51 | 1 | 0 | 2 | 1 | 96%
aiopromql/models/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | 44 | 4 | 0 | 2 | 0 | 91%
aiopromql/models/prometheus.py | 36 | 0 | 0 | 6 | 0 | 100%
aiopromql/utils.py | 10 | 0 | 0 | 4 | 0 | 100%
Total | 144 | 5 | 0 | 14 | 1 | 96%

No items found using the specified filter.